@@ -25,7 +25,7 @@ def callback_func(interface, method, arguments, user_data):
     # realparams  exact input filename string (no fixup)
     # realparams2 only fixup is to ensure filename does not start with file://
     # params      substitutes troublesome symbols to hex encodings and ensures it starts with file://
-    # params2     hex encoded symbols (as above) but ensure does NOT start with file://
+    # params2     hex encoded symbols (as above) but ensure does NOT start with file:// 
 
     # fixup1 strips off the extra stuff added by Maemo 5.
 
@@ -83,9 +83,11 @@ def callback_func(interface, method, arguments, user_data):
     print "-- realparams2 : " + realparams2
     print "------"
 
-    docmimetype = gnomevfs.get_mime_type(params2)
-    print "-- params2 mimetype is:  %s " % docmimetype
-    print "------"
+    docmimetype = "application/octet-stream"
+    if '://' not in params2:
+      docmimetype = gnomevfs.get_mime_type(params2)
+      print "-- params2 mimetype is:  %s " % docmimetype
+      print "------"
 
     #verify our configuration files exist in /home/user
     if (os.path.exists("/usr/lib/dbus-switchboard/dbus-switch-xref.cfg") and os.path.exists("/usr/lib/dbus-switchboard/dbus-switch-apps.cfg")):
